@@ -4,7 +4,7 @@ from ..models.project import Project
 
 @admin.register(Project)
 class ProjectAdmin(admin.ModelAdmin):
-    list_display = ('project_key', 'name', 'server')
+    list_display = ('project_key', 'name', 'server', 'category')
     search_fields = ('project_key', 'name')
-    readonly_fields = ('project_key', 'name', 'project_id', 'server')
+    readonly_fields = ('project_key', 'name', 'project_id', 'server', 'category')
     list_filter = ('server',)
